@@ -23,9 +23,9 @@ class.  For those wishing to override the braille generators, however,
 one can create a new instance and replace/extend the braille
 generators as they see fit."""
 
-__id__        = "$Id: braillegenerator.py 3222 2007-11-06 20:38:59Z richb $"
-__version__   = "$Revision: 3222 $"
-__date__      = "$Date: 2007-11-06 15:38:59 -0500 (Tue, 06 Nov 2007) $"
+__id__        = "$Id: braillegenerator.py 3379 2007-12-14 21:14:42Z richb $"
+__version__   = "$Revision: 3379 $"
+__date__      = "$Date: 2007-12-14 16:14:42 -0500 (Fri, 14 Dec 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -164,21 +164,10 @@ class BrailleGenerator:
 
         if settings.brailleVerbosityLevel == settings.VERBOSITY_LEVEL_VERBOSE:
             text = ""
-
-            result = self._script.getAcceleratorAndShortcut(obj)
-
-            accelerator = result[0]
-            #shortcut = result[1]
-
+            result = self._script.getKeyBinding(obj)
+            accelerator = result[2]
             if len(accelerator) > 0:
                 text += "(" + accelerator + ")"
-
-            # [[[TODO: WDW - various stuff preserved while we work out the
-            # desired verbosity here.]]]
-            #
-            #if len(shortcut) > 0:
-            #    text += "(" + shortcut + ")"
-
             return text
         else:
             return None
@@ -332,12 +321,19 @@ class BrailleGenerator:
 
         self._debugGenerator("_getBrailleRegionsForCheckBox", obj)
 
+        state = obj.getState()
+        if state.contains(pyatspi.STATE_INDETERMINATE):
+            indicatorindex = 2
+        elif state.contains(pyatspi.STATE_CHECKED):
+            indicatorindex = 1
+        else:
+            indicatorindex = 0
+
         text = ""
         state = obj.getState()
         text = self._script.appendString(
             text,
-            settings.brailleCheckBoxIndicators[
-                int(state.contains(pyatspi.STATE_CHECKED))])
+            settings.brailleCheckBoxIndicators[indicatorindex])
 
         text = self._script.appendString(
             text, self._script.getDisplayedLabel(obj))
@@ -366,12 +362,19 @@ class BrailleGenerator:
 
         self._debugGenerator("_getBrailleRegionsForCheckMenuItem", obj)
 
+        state = obj.getState()
+        if state.contains(pyatspi.STATE_INDETERMINATE):
+            indicatorindex = 2
+        elif state.contains(pyatspi.STATE_CHECKED):
+            indicatorindex = 1
+        else:
+            indicatorindex = 0
+
         text = ""
         state = obj.getState()
         text = self._script.appendString(
             text,
-            settings.brailleCheckBoxIndicators[
-                int(state.contains(pyatspi.STATE_CHECKED))])
+            settings.brailleCheckBoxIndicators[indicatorindex])
 
         text = self._script.appendString(
             text, self._script.getDisplayedLabel(obj))
@@ -427,9 +430,21 @@ class BrailleGenerator:
             regions.append(braille.Region(label + " "))
             focusedRegionIndex = 1
 
-        displayedText = self._script.getDisplayedText(obj)
-        if displayedText:
-            regions.append(braille.Region(displayedText))
+        # Check to see if the text is editable. If so, then we want
+        # to show the text attributes (such as selection -- see bug
+        # 496846 for more details).
+        #
+        textObj = None
+        for child in obj:
+            if child and child.getRole() == pyatspi.ROLE_TEXT:
+                textObj = child
+        if textObj and textObj.getState().contains(pyatspi.STATE_EDITABLE):
+            textRegion = braille.Text(textObj)
+            regions.append(textRegion)
+        else:
+            displayedText = self._script.getDisplayedText(obj)
+            if displayedText:
+                regions.append(braille.Region(displayedText))
 
         regions.append(braille.Region(
             " " + rolenames.getBrailleForRoleName(obj)))
@@ -597,7 +612,16 @@ class BrailleGenerator:
 
         self._debugGenerator("_getBrailleRegionsForLabel", obj)
 
-        return self._getDefaultBrailleRegions(obj)
+        regions = []
+
+        textRegion = braille.Text(obj,
+                                  self._script.getDisplayedLabel(obj),
+                                  " $l")
+        regions.append(textRegion)
+
+        # We do not want the role at the end of text areas.
+
+        return [regions, textRegion]
 
     def _getBrailleRegionsForList(self, obj):
         """Get the braille for a list.
