@@ -20,9 +20,9 @@
 """Uses speech prompts and a command line interface to set Orca
 user preferences."""
 
-__id__        = "$Id: orca_console_prefs.py 3081 2007-10-17 18:12:10Z richb $"
-__version__   = "$Revision: 3081 $"
-__date__      = "$Date: 2007-10-17 14:12:10 -0400 (Wed, 17 Oct 2007) $"
+__id__        = "$Id: orca_console_prefs.py 3269 2007-11-29 16:28:17Z wwalker $"
+__version__   = "$Revision: 3269 $"
+__date__      = "$Date: 2007-11-29 11:28:17 -0500 (Thu, 29 Nov 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -82,7 +82,7 @@ def sayAndPrint(text,
                 stop=False,
                 getInput=False,
                 speechServer=None,
-                acss=None):
+                voice=None):
     """Prints the given text.  In addition, if the text field
     is not None, speaks the given text, optionally interrupting
     anything currently being spoken.
@@ -92,7 +92,7 @@ def sayAndPrint(text,
     - stop: if True, interrupt any speech currently being spoken
     - getInput: if True, elicits raw input from the user and returns it
     - speechServer: the speech server to use
-    - acss: the ACSS to use for speaking
+    - voice: the ACSS to use for speaking
 
     Returns raw input from the user if getInput is True.
     """
@@ -103,9 +103,9 @@ def sayAndPrint(text,
             speechServer.stop()
 
     if speechServer:
-        speechServer.speak(text, acss)
+        speechServer.speak(text, voice)
     else:
-        speech.speak(text, acss)
+        speech.speak(text, voice)
 
     if getInput:
         return raw_input(text)
@@ -416,6 +416,7 @@ def logoutUser():
     """Automatically log the user out of the GNOME desktop."""
 
     import gnome
+    import gnome.ui
 
     gnome.init(platform.package, platform.version)
     client = gnome.ui.master_client()
