@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -21,19 +21,17 @@
 of manipulating text - both the user and the system put text into the
 system and we try to determine which was which and why."""
 
-__id__        = "$Id: gnome-terminal.py,v 1.16 2006/10/19 18:16:54 richb Exp $"
-__version__   = "$Revision: 1.16 $"
-__date__      = "$Date: 2006/10/19 18:16:54 $"
+__id__        = "$Id: gnome-terminal.py 3295 2007-11-29 23:08:59Z richb $"
+__version__   = "$Revision: 3295 $"
+__date__      = "$Date: 2007-11-29 18:08:59 -0500 (Thu, 29 Nov 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import orca.atspi as atspi
-import orca.debug as debug
+import pyatspi
+
 import orca.default as default
 import orca.input_event as input_event
-import orca.util as util
 import orca.orca_state as orca_state
-import orca.rolenames as rolenames
 import orca.settings as settings
 import orca.speech as speech
 
@@ -67,7 +65,7 @@ class Script(default.Script):
     #
     #    # Now we find the focused object and set the locus of focus to it.
     #    #
-    #    obj = util.findFocusedObject(self.app)
+    #    obj = self.findFocusedObject(self.app)
     #    if obj:
     #        orca.setLocusOfFocus(event, obj)
     #    else:
@@ -83,14 +81,14 @@ class Script(default.Script):
         if orca_state.lastInputEvent \
                and isinstance(orca_state.lastInputEvent,
                               input_event.KeyboardEvent):
-            event_string = orca_state.lastInputEvent.event_string
+            event_string = orca_state.lastNonModifierKeyEvent.event_string
         else:
             event_string = None
 
         # We only do special things when people press backspace
         # in terminals.
         #
-        if (event.source.role != rolenames.ROLE_TERMINAL) \
+        if (event.source.getRole() != pyatspi.ROLE_TERMINAL) \
             or (event_string != "BackSpace"):
             default.Script.onTextDeleted(self, event)
             return
@@ -107,7 +105,7 @@ class Script(default.Script):
 
         # Speak the character that has just been deleted.
         #
-        character = event.any_data.value().decode("UTF-8")[0].encode("UTF-8")
+        character = event.any_data.decode("UTF-8")[0].encode("UTF-8")
         if character.isupper():
             speech.speak(character, self.voices[settings.UPPERCASE_VOICE])
         else:
@@ -122,7 +120,7 @@ class Script(default.Script):
 
         # We only do special things for terminals.
         #
-        if event.source.role != rolenames.ROLE_TERMINAL:
+        if event.source.getRole() != pyatspi.ROLE_TERMINAL:
             default.Script.onTextInserted(self, event)
             return
 
@@ -136,7 +134,7 @@ class Script(default.Script):
 
         self.updateBraille(event.source)
 
-        text = event.any_data.value()
+        text = event.any_data
 
         # When one does a delete in a terminal, the remainder of the
         # line is "inserted" instead of being shifted left.  We will
@@ -147,66 +145,72 @@ class Script(default.Script):
         # We'll let our super class handle "Delete".  We'll handle Ctrl+D.
         #
 
-        if not orca_state.lastInputEvent or \
-            not isinstance(orca_state.lastInputEvent,
-                           input_event.KeyboardEvent):
+        if not orca_state.lastInputEvent:
             return
 
-        keyString = orca_state.lastInputEvent.event_string
-
-        controlPressed = orca_state.lastInputEvent.modifiers \
-                         & (1 << atspi.Accessibility.MODIFIER_CONTROL)
-
-        if (keyString == "Delete") or (keyString == "BackSpace"):
-            return
-        elif (keyString == "D") and controlPressed:
-            text = text.decode("UTF-8")[0].decode("UTF-8")
-
-        # If the last input event was a keyboard event, check to see if
-        # the text for this event matches what the user typed. If it does,
-        # then don't speak it.
-        #
-        # Note that the text widgets sometimes compress their events,
-        # thus we might get a longer string from a single text inserted
-        # event, while we also get individual keyboard events for the
-        # characters used to type the string.  This is ugly.  We attempt
-        # to handle it here by only echoing text if we think it was the
-        # result of a command (e.g., a paste operation).
-        #
-        # Note that we have to special case the space character as it
-        # comes across as "space" in the keyboard event and " " in the
-        # text event.
-        #
-        # For terminal, Return usually ends up in more text from the
-        # system, which we want to hear.  Tab is also often used for
-        # command line completion, so we want to hear that, too.
-        #
-        # Finally, if we missed some command and the system is giving
-        # us a string typically longer than what the length of a
-        # compressed string is (we choose 5 here), then output that.
-        #
         matchFound = False
+        speakThis = False
         if isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent):
+            keyString = orca_state.lastNonModifierKeyEvent.event_string
+
+            controlPressed = orca_state.lastInputEvent.modifiers \
+                             & (1 << pyatspi.MODIFIER_CONTROL)
+
+            if (keyString == "Delete") or (keyString == "BackSpace"):
+                return
+            elif (keyString == "D") and controlPressed:
+                text = text.decode("UTF-8")[0].decode("UTF-8")
+
+            # If the last input event was a keyboard event, check to see if
+            # the text for this event matches what the user typed. If it does,
+            # then don't speak it.
+            #
+            # Note that the text widgets sometimes compress their events,
+            # thus we might get a longer string from a single text inserted
+            # event, while we also get individual keyboard events for the
+            # characters used to type the string.  This is ugly.  We attempt
+            # to handle it here by only echoing text if we think it was the
+            # result of a command (e.g., a paste operation).
+            #
+            # Note that we have to special case the space character as it
+            # comes across as "space" in the keyboard event and " " in the
+            # text event.
+            #
+            # For terminal, Return usually ends up in more text from the
+            # system, which we want to hear.  Tab is also often used for
+            # command line completion, so we want to hear that, too.
+            #
+            # Finally, if we missed some command and the system is giving
+            # us a string typically longer than what the length of a
+            # compressed string is (we choose 5 here), then output that.
+            #
             wasCommand = orca_state.lastInputEvent.modifiers \
-                         & (1 << atspi.Accessibility.MODIFIER_CONTROL \
-                            | 1 << atspi.Accessibility.MODIFIER_ALT \
-                            | 1 << atspi.Accessibility.MODIFIER_META \
-                            | 1 << atspi.Accessibility.MODIFIER_META2 \
-                            | 1 << atspi.Accessibility.MODIFIER_META3)
+                         & (1 << pyatspi.MODIFIER_CONTROL \
+                            | 1 << pyatspi.MODIFIER_ALT \
+                            | 1 << pyatspi.MODIFIER_META \
+                            | 1 << pyatspi.MODIFIER_META2 \
+                            | 1 << pyatspi.MODIFIER_META3)
             wasCommand = wasCommand \
                          or (keyString == "Return") \
                          or (keyString == "Tab")
             if (text == " " and keyString == "space") \
                 or (text == keyString):
                 matchFound = True
-                pass
             elif wasCommand or (len(text) > 5):
-                if text.isupper():
-                    speech.speak(text, self.voices[settings.UPPERCASE_VOICE])
-                else:
-                    speech.speak(text)
+                speakThis = True
+
+        elif isinstance(orca_state.lastInputEvent, \
+                        input_event.MouseButtonEvent) and \
+             orca_state.lastInputEvent.button == "2":
+            speakThis = True
+
+        if speakThis:
+            if text.isupper():
+                speech.speak(text, self.voices[settings.UPPERCASE_VOICE])
+            else:
+                speech.speak(text)
 
         if settings.enableEchoByWord \
-           and util.isWordDelimiter(text.decode("UTF-8")[-1:]):
+           and self.isWordDelimiter(text.decode("UTF-8")[-1:]):
             if matchFound:
                 self.echoPreviousWord(event.source)
