@@ -19,23 +19,13 @@
 
 """Custom script for gnome_segv2."""
 
-__id__        = "$Id: gnome_segv2.py 2126 2007-03-06 21:35:17Z richb $"
-__version__   = "$Revision: 2126 $"
-__date__      = "$Date: 2007-03-06 16:35:17 -0500 (Tue, 06 Mar 2007) $"
+__id__        = "$Id: gnome_segv2.py 3123 2007-10-19 21:15:28Z richb $"
+__version__   = "$Revision: 3123 $"
+__date__      = "$Date: 2007-10-19 17:15:28 -0400 (Fri, 19 Oct 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import orca.debug as debug
 import orca.default as default
-import orca.atspi as atspi
-import orca.rolenames as rolenames
-import orca.orca as orca
-import orca.braille as braille
-import orca.speech as speech
-import orca.settings as settings
-
-from orca.orca_i18n import _ # for gettext support
-
 
 ########################################################################
 #                                                                      #
