@@ -20,9 +20,9 @@
 """Manages the default speech server for orca.  A script can use this
 as its speech server, or it can feel free to create one of its own."""
 
-__id__        = "$Id: speech.py 3018 2007-10-11 17:44:04Z wwalker $"
-__version__   = "$Revision: 3018 $"
-__date__      = "$Date: 2007-10-11 13:44:04 -0400 (Thu, 11 Oct 2007) $"
+__id__        = "$Id: speech.py 3276 2007-11-29 18:31:01Z richb $"
+__version__   = "$Revision: 3276 $"
+__date__      = "$Date: 2007-11-29 13:31:01 -0500 (Thu, 29 Nov 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -95,7 +95,7 @@ def init():
                               [''])
     except:
         try:
-            moduleName = moduleName.replace("orca.","",1)
+            moduleName = moduleName.replace("orca.", "", 1)
             factory =  __import__(moduleName,
                                   globals(),
                                   locals(),
@@ -160,32 +160,32 @@ def speak(text, acss=None, interrupt=True):
     if _speechserver:
         _speechserver.speak(text, __resolveACSS(acss), interrupt)
 
-def speakKeyEvent(event_string, type):
+def speakKeyEvent(event_string, eventType):
     """Speaks a key event immediately.
 
     Arguments:
     - event_string: string representing the key event as defined by
                     input_event.KeyboardEvent.
-    - type:         key event type as one of orca.KeyEventType constants.
+    - eventType:    key event type as one of orca.KeyEventType constants.
 
     """
     if settings.silenceSpeech:
         return
 
     if _speechserver:
-        _speechserver.speakKeyEvent(event_string, type)
+        _speechserver.speakKeyEvent(event_string, eventType)
     else:
         # Check to see if there are localized words to be spoken for
         # this key event.
         #
         event_string = keynames.getKeyName(event_string)
 
-        if type == orca.KeyEventType.LOCKING_LOCKED:
+        if eventType == orca.KeyEventType.LOCKING_LOCKED:
             # Translators: this represents the state of a locking modifier
             # key (e.g., Caps Lock)
             #
             event_string += " " + _("on")
-        elif type == orca.KeyEventType.LOCKING_UNLOCKED:
+        elif eventType == orca.KeyEventType.LOCKING_UNLOCKED:
             # Translators: this represents the state of a locking modifier
             # key (e.g., Caps Lock)
             #
@@ -234,6 +234,13 @@ def speakUtterances(utterances, acss=None, interrupt=True):
                                        __resolveACSS(acss),
                                        interrupt)
 
+def getInfo():
+    info = None
+    if _speechserver:
+        info = _speechserver.getInfo()
+
+    return info
+
 def stop():
     if _speechserver:
         _speechserver.stop()
@@ -285,7 +292,6 @@ def shutdown():
         _speechserver = None
 
 def reset(text=None, acss=None):
-    global _speechserver
     if _speechserver:
         _speechserver.reset(text, acss)
 
@@ -317,4 +323,3 @@ def test():
                 server.shutdown()
             except:
                 debug.printException(debug.LEVEL_OFF)
-                pass
